@@ -10,7 +10,7 @@ require POSIX;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '1.11'; # keep same as in Tty.pm
+$VERSION = '1.14'; # keep same as in Tty.pm
 
 @ISA = qw(IO::Handle);
 eval { local $^W = 0; undef local $SIG{__DIE__}; require IO::Stty };
@@ -93,7 +93,7 @@ sub make_slave_controlling_terminal {
   }
 
   # Create a new 'session', lose controlling terminal.
-  if (not POSIX::setsid()) {
+  if (POSIX::setsid() == -1) {
     warn "setsid() failed, strange behavior may result: $!\r\n" if $^W;
   }
 
@@ -155,7 +155,7 @@ IO::Pty - Pseudo TTY object class
 
 =head1 VERSION
 
-1.11
+1.14
 
 =head1 SYNOPSIS
 
@@ -181,7 +181,7 @@ C<IO::Pty> provides an interface to allow the creation of a pseudo tty.
 C<IO::Pty> inherits from C<IO::Handle> and so provide all the methods
 defined by the C<IO::Handle> package.
 
-Please note that pty creation is very system-dependend.  If you have
+Please note that pty creation is very system-dependent.  If you have
 problems, see L<IO::Tty> for help.
 
 
